@@ -196,9 +196,7 @@ func New(ops Options) (c *Client, err error) {
 		return
 	}
 	// Create a hash of part of the shared secret to use as the room name
-	// add the current day and "croc" to the shared secret to make more resistant
-	// to rainbow tables
-	hashExtra := "croc" + time.Now().Format("2006-01-02")
+	hashExtra := "croc"
 	roomNameBytes := sha256.Sum256([]byte(c.Options.SharedSecret[:4] + hashExtra))
 	c.Options.RoomName = hex.EncodeToString(roomNameBytes[:])
 
@@ -1211,8 +1209,7 @@ func (c *Client) processMessageFileInfo(m message.Message) (done bool, err error
 		if strings.Contains(c.FilesToTransfer[i].FolderRemote, ".ssh") {
 			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
 		}
-		// Issue #595 - disallow filenames with anything but 0-9a-zA-Z.-_. and / characters
-
+		// Issue #595 - disallow filenames with invisible characters
 		if !utils.ValidFileName(path.Join(c.FilesToTransfer[i].FolderRemote, fi.Name)) {
 			return true, fmt.Errorf("invalid filename detected: '%s'", fi.Name)
 		}
